@@ -1,9 +1,5 @@
-library(testthat)
-library(ggside)
 library(vdiffr)
 
-context("ggside custom side scales")
-
 test_that("xsidey and ysidex appear",{
   p <- ggplot(mpg, aes(displ, hwy, colour = class)) +
     geom_point(size = 2) +
